#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=ahel6.96_tt4_near_source.ps
projection=-JX18/12
region=-R0/1.2/-10/10
gmt psbasemap $region $projection -Bxa0.1f0.1+l'Epicentral Distance (deg)' -Bya5f1g5+l'Travel Time Residual (s)' -BWeSn+t'Near-Source ahel6.96' -K > $psfile
# Distance limit for hypocentroid
gmt psxy -: -R $projection -Wthick,black,- -O -K << END >> $psfile
-10.000    1.200
10.000    1.200
END
# Pg arrivals
gmt psxy -: -R $projection -Sx -Wthick,red -K -O << END >> $psfile
     0.498     1.120     0.200
     0.327     1.120     0.200
     1.367     1.006     0.200
     0.213     1.194     0.200
     0.354     1.194     0.200
    -0.138     1.026     0.200
    -0.082     1.101     0.200
    -0.426     1.121     0.200
    -0.082     1.131     0.200
    -0.271     1.126     0.200
    -0.044     1.164     0.200
     0.288     0.794     0.200
    -0.688     0.794     0.200
    -0.289     0.602     0.200
     0.138     0.791     0.200
    -0.002     0.896     0.200
    -0.485     0.882     0.200
    -0.645     0.882     0.200
    -0.660     0.541     0.200
    -0.060     1.177     0.200
     0.850     1.177     0.200
     0.049     1.177     0.200
     0.344     1.091     0.200
    -0.453     1.091     0.200
    -0.014     1.073     0.200
     0.127     1.073     0.200
     0.291     0.906     0.200
    -0.116     0.906     0.200
     0.003     0.962     0.200
    -0.337     1.005     0.200
    -0.228     1.005     0.200
    -0.488     0.975     0.200
    -0.210     0.993     0.200
    -0.685     0.948     0.200
    -0.943     1.037     0.200
     0.883     0.962     0.200
    -0.593     0.976     0.200
     0.051     1.177     0.200
     0.304     0.707     0.200
     0.756     1.132     0.200
     0.225     1.120     0.200
     0.214     0.962     0.200
    -0.831     0.901     0.200
     0.141     0.974     0.200
     0.467     0.852     0.200
     0.482     0.996     0.200
     0.214     1.159     0.200
     0.086     0.971     0.200
    -0.035     0.882     0.200
     0.808     0.963     0.200
     0.011     0.763     0.200
     0.985     0.982     0.200
END
# Pb arrivals
gmt psxy -: -R $projection -Sx -Wthick,blue -K -O << END >> $psfile
END
# Pn arrivals
gmt psxy -: -R $projection -Sx -Wthick,green -K -O << END >> $psfile
     0.299     1.158     0.200
    -0.031     1.158     0.200
END
# Sg arrivals
gmt psxy -: -R $projection -Sc -Wthick,red -K -O << END >> $psfile
     0.662     1.120     0.200
    -0.204     1.194     0.200
     0.007     1.194     0.200
     0.210     1.194     0.200
    -0.262     1.026     0.200
    -0.747     1.091     0.200
    -0.520     1.091     0.200
    -0.349     1.073     0.200
    -0.156     1.011     0.200
    -0.308     0.993     0.200
     0.479     0.826     0.200
END
# Sb arrivals
gmt psxy -: -R $projection -Sc -Wthick,blue -K -O << END >> $psfile
END
# Sn arrivals
gmt psxy -: -R $projection -Sc -Wthick,green -K -O << END >> $psfile
     0.524     1.131     0.200
    -0.198     1.158     0.200
    -1.118     1.158     0.200
     0.754     1.177     0.200
     0.254     1.177     0.200
    -0.679     1.073     0.200
    -0.046     1.073     0.200
END
# Average Pg residual
gmt psxy -: -R $projection -Wthicker,red -K -O << END >> $psfile
 0.03    0.000
 0.03    1.200
END
# Average Pn residual
gmt psxy -: -R $projection -Wthicker,green -K -O << END >> $psfile
 0.13    0.000
 0.13    1.200
END
# Average Sg residual
gmt psxy -: -R $projection -Wthin,red,- -K -O << END >> $psfile
-0.11    0.0
-0.11    1.2
END
# Average Sn residual
gmt psxy -: -R $projection -Wthin,green,- -K -O << END >> $psfile
-0.07    0.0
-0.07    1.2
END
gmt pstext -: -R $projection -F+f12p,Helvetica-Bold,black+a0.+jBL -O << END >> $psfile
     9.000     0.025   Residuals for crustal phases, average over (0-1.2)
     8.000     0.050   Pg = red x; average =   0.0 (solid red line)
     6.000     0.050   Pn = green x; average =   0.1 (solid green line)
    -7.500     0.050   Sg = red circles; average =  -0.1 (dashed red line)
    -9.500     0.050   Sn = green circles; average =  -0.1 (dashed green line)
END
